Attribute VB_Name = "Validation_routines"
Attribute VB_Description = "Validation Routines"
'This module contains data validation routines.
'For global use

Public Function validate_loan_duration(Data_focus As Object) As Boolean
    Dim Add_line As Boolean

    Data_focus.Text = Trim(Data_focus.Text)
    Title$ = "Loan Duration Error"
    
    months = Int(Val(Left$(Data_focus.Text, 2)))
    days = Int(Val(Mid$(Data_focus.Text, 4, 2)))
    M_char$ = UCase(Mid(Data_focus.Text, 3, 1))
    D_char$ = UCase(Mid(Data_focus.Text, 6, 1))
    
    If Data_focus.Text = "" Then
        Data_focus.Text = "00M00D"
    ElseIf Len(Data_focus.Text) <> 6 Or M_char$ <> "M" Or D_char$ <> "D" Then
        msg$ = "Invalid duration format. The acceptable format is **M**D "
        msg$ = msg$ + "where * represents a digit. Consult help for more information."
    Else
        Add_line = True
        If months < 0 Or months > 12 Then
            msg$ = "The number of months must range from 00 to 12"
        End If
        If days < 0 Or days > 31 Then
            msg$ = msg$ + New_line + "The number of days must range from 00 to 31"
        End If
    End If
    
    If months = 1 Then
        months_str$ = Format$(months, "#0 ") + "Month"
    Else
        months_str$ = Format$(months, "#0 ") + "Months"
    End If
    
    If days = 1 Then
        days_str$ = Format$(days, "  #0 ") + "Day"
    Else
        days_str$ = Format$(days, "  #0 ") + "Days"
    End If
        
    If msg$ <> "" Then
        If Add_line = True Then
            msg$ = msg$ + New_line + "Your loan period had been interpreted"
            msg$ = msg$ + New_line + " as " + months_str$ + days_str$
        End If
        MsgBox msg$, buttons, Title$
        validate_loan_duration = False
        If Data_focus.Parent.Name = "frmSetup" Then
            'display the appropriate group
            frmSetup.SSTabOptions.Tab = 2
        End If
        Data_focus.SetFocus
    Else
        loanperiod$ = (Format$(months, "00") + "M" + Format$(days, "00") + "D")
        Data_focus.Text = loanperiod$
        validate_loan_duration = True
    End If
    
    
End Function

Public Function Confirm_loan_duration(Data_focus As Object) As Boolean
    months = Int(Val(Left$(Data_focus.Text, 2)))
    days = Int(Val(Mid$(Data_focus.Text, 4, 2)))
    
    If months = 1 Then
        months_str$ = Format$(months, "#0 ") + "Month"
    Else
        months_str$ = Format$(months, "#0 ") + "Months"
    End If
    
    If days = 1 Then
        days_str$ = Format$(days, "  #0 ") + "Day"
    Else
        days_str$ = Format$(days, "  #0 ") + "Days"
    End If
    
    msg$ = "You loan period has been interpreted as " + New_line
    msg$ = msg$ + months_str$ + days_str$ + New_line
    msg$ = msg$ + "Is this correct?"
    Response% = MsgBox(msg$, vbYesNo + vbQuestion, "Confirm Loan Period")
    If Response% = vbNo Then
           Confirm_loan_duration = False
           If Data_focus.Parent.Name = "frmSetup" Then
                SSLimits.Value = True
           End If
           Data_focus.SetFocus
    Else
           Confirm_loan_duration = True
    End If
    
End Function

Public Function Validate_date(Data_focus As Object, Text As String)
    Dim Add_line As Boolean
    
    Title$ = "Date Error"
    buttons = vbExclamation + vbOKOnly
    
    date_part = Int(Val(Left$(Data_focus.Text, 2)))
    month_part = Int(Val(Mid$(Data_focus.Text, 4, 2)))
    year_part = Int(Val(Mid$(Data_focus.Text, 7, 4)))
    
    Data_focus.Text = Trim(Data_focus.Text)
    msg$ = ""
    
    If Data_focus.Text = "" Then
        msg$ = "Enter " + Text
    ElseIf Len(Data_focus.Text) <> 10 Or date_part = 0 Or month_part = 0 Or year_part = 0 Then
        msg$ = "Invalid date format. "
        msg$ = msg$ + "Acceptable format is dd/mm/yyyy"
        msg$ = msg$ + " without any leading spaces. Zero Values are not allowed "
        msg$ = msg$ + "and the date should be 10 characters long."
    Else
        Add_line = True
        If date_part < 1 Or date_part > 31 Then
            msg$ = "The day must range from 1 to 31"
        End If
        
        If month_part < 1 Or month_part > 12 Then
            msg$ = msg$ + New_line + " The value for the month must range from 1 to 12"
        End If
        
        If year_part < 1800 Or year_part > 2100 Then
            msg$ = msg$ + New_line + "The  year must range from 1800 to 2100"
        End If
    End If
        
    date_part_string = Format$(date_part, "00")
    month_part_string = Format$(month_part, "00")
    year_part_string = Format$(year_part, "0000")
    
    
    If msg$ <> "" Then
        If Add_line Then
            msg$ = msg$ + New_line + "Your " + Text + " had been interpreted as "
            msg$ = msg$ + New_line + date_part_string + "/" + month_part_string _
                + "/" + year_part_string
        End If
        MsgBox msg$, buttons, Title$
        Data_focus.SetFocus
        Validate_date = False
    Else
        Validate_date = True
    End If
    
    
End Function

Public Function Confirm_date(Data_focus As Object, Text As String)
    
    convert# = Get_date_number(Data_focus)
    msg$ = Format$(convert#, "dddd dd mmmm yyyy")
    msg$ = "The date you entered for the " + Text + " data item has been interpreted as :" + New_line + msg$
    msg$ = msg$ + New_line + "Is this correct?"
    Response% = MsgBox(msg$, vbYesNo + vbQuestion, "Confirm date")
    If Response% = vbNo Then
        Data_focus.SetFocus
        Confirm_date = False
    Else
        Data_focus.Text = Format$(convert#, "dd/mm/yyyy")
        Confirm_date = True
    End If
    
End Function

Public Function validate_text _
            (Data_spotlight As Object, Limit%, description$, allow_null) _
            As Boolean
    
    
    Const buttons = vbExclamation + vbOKOnly
    Const Title$ = "Error"

    msg$ = ""
    myText$ = Trim(Data_spotlight.Text)
    Do
        Character = Left(myText$, 1)
        If Character = Chr(10) Or Character = Chr(13) Then
            myText$ = Right(myText$, Len(myText$) - 1)
        Else
            Character = Left(myText$, 1)
            If Character = Chr(10) Or Character = Chr(13) Then
                myText$ = Right(myText$, Len(myText$) - 1)
            Else
                'no more leading or trailing carriage returns or line feeds
                Text_fully_trimmed = True
            End If
        End If
    Loop Until myText$ = "" Or Text_fully_trimmed
    Data_spotlight.Text = myText$
    
    If Len(Data_spotlight.Text) > Limit Then
        msg$ = description$ + " cannot be longer than " + Str$(Limit) + " characters"
    ElseIf Data_spotlight.Text = "" Then
        If allow_null = 1 Then
            msg$ = "Enter " + description$
        Else
            Let Data_spotlight.Text = "(none)"
        End If
    End If
    
    If msg$ <> "" Then
        MsgBox msg$, buttons, Title$
        validate_text = False
        If Data_spotlight.Parent.Name = "frmsetup" Then Exit Function
        Data_spotlight.SetFocus
        Exit Function
    Else
        validate_text = True
    End If
    
End Function

Public Function validate_numbers(Data_spotlight As Object, lower_limit, _
        upper_limit, description$) As Boolean
    
    Const buttons = vbOKOnly + vbExclamation
     
    Title$ = "Error"
    msg$ = ""
    
    Let Number_to_be_tested = Val(Data_spotlight.Text)
    
    If Int(Number_to_be_tested) <> Number_to_be_tested Then
         msg$ = "The " + description$ + " must be a whole number"
    ElseIf Number_to_be_tested < lower_limit Then
         msg$ = "The " + description$ + " must be greater than " + Str$(lower_limit)
    ElseIf Number_to_be_tested > upper_limit Then
         msg$ = "The " + description$ + " must be less than or equal to " + Str$(upper_limit)
    Else
         Let Data_spotlight.Text = Trim(Str$(Number_to_be_tested))
    End If
    
    If msg$ <> "" Then   'error occured
         MsgBox msg$, buttons, Title$
         If Data_spotlight.Parent.Name = "frmSetup" Then Exit Function
         Data_spotlight.SetFocus
    Else
        validate_numbers = True
    End If
    
End Function

Public Function validate_subscriberID(Data_focus As Object) As Boolean
    Dim Error_position As Integer
    Dim Counter As Integer
    Dim Error_found As Boolean
    
    buttons = vbExclamation + vbOKOnly
    If Len(Data_focus.Text) < 8 Then
        msg$ = "The Subscriber ID code must be 8 characters long"
        MsgBox msg$, buttons, "Subscriber ID Input Error"
        validate_subscriberID = False
        Data_focus.SetFocus
        Exit Function
    End If
    
    msg$ = ""
    For Counter = 1 To 8
        Character = Mid$(Data_focus.Text, Counter, 1)
        If Subscriber_Id_format(Counter) = "L" Then
            If Asc(UCase$(Character)) < 65 Or Asc(UCase$(Character)) > 90 Then
                Error_found = True
                Error_position = Counter
                Expected$ = "letter."
            Else
                Error_found = False
            End If
        ElseIf Subscriber_Id_format(Counter) = "D" Then
            If Asc(UCase$(Character)) < 48 Or Asc(UCase$(Character)) > 57 Then
                Error_found = True
                Error_position = Counter
                Expected$ = "digit."
            Else
                Error_found = False
            End If
        Else
            MsgBox "Unable to validate Subscriber ID.", vbCritical, "Warning"
        End If
        
        If Error_found Then
            Select Case Error_position
                Case 1
                    Position$ = "first"
                Case 2
                    Position$ = "second"
                Case 3
                    Position$ = "third"
                Case 4
                    Position$ = "fourth"
                Case 5
                    Position$ = "fifth"
                Case 6
                    Position$ = "sixth"
                Case 7
                    Position$ = "seventh"
                Case 8
                    Position$ = "eighth"
            End Select
            
            msg$ = msg$ + "The " + Position$ + " character must be a "
            msg$ = msg$ + Expected$ + New_line
        End If
        
    Next Counter

            
    If msg$ <> "" Then
        MsgBox msg$, buttons, "Subscriber ID Input Error"
        Data_focus.SetFocus
        validate_subscriberID = False
    Else
        validate_subscriberID = True
    End If
                
End Function


Public Function Compare_text(Text1 As String, Text2 As String) As Boolean
    'Perform a case insensitive search
    
    If UCase(Trim(Text1)) = UCase(Trim(Text2)) Then
        Compare_text = True
    Else
        Compare_text = False
    End If

End Function
